@@ -20,6 +20,10 @@
  * Author: David Zeuthen <davidz@redhat.com>
  */
 
+#if !defined (__GIO_GIO_H_INSIDE__) && !defined (GIO_COMPILATION)
+#error "Only <gio/gio.h> can be included directly."
+#endif
+
 #ifndef __G_DBUS_CONNECTION_H__
 #define __G_DBUS_CONNECTION_H__
 
@@ -430,7 +434,7 @@ gboolean         g_dbus_connection_unregister_subtree         (GDBusConnection
  * @connection: A #GDBusConnection.
  * @sender_name: The unique bus name of the sender of the signal.
  * @object_path: The object path that the signal was emitted on.
- * @interface_name: The name of the signal.
+ * @interface_name: The name of the interface.
  * @signal_name: The name of the signal.
  * @parameters: A #GVariant tuple with parameters for the signal.
  * @user_data: User data passed when subscribing to the signal.
