@@ -134,7 +134,7 @@ g_dbus_message_new (void)
  * g_dbus_message_new_method_call:
  * @name: A valid D-Bus name or %NULL.
  * @path: A valid object path.
- * @interface: A valid D-Bus interface name or %NULL.
+ * @interface_: A valid D-Bus interface name or %NULL.
  * @method: A valid method name.
  *
  * Creates a new #GDBusMessage for a method call.
@@ -146,7 +146,7 @@ g_dbus_message_new (void)
 GDBusMessage *
 g_dbus_message_new_method_call (const gchar *name,
                                 const gchar *path,
-                                const gchar *interface,
+                                const gchar *interface_,
                                 const gchar *method)
 {
   GDBusMessage *message;
@@ -154,7 +154,7 @@ g_dbus_message_new_method_call (const gchar *name,
   g_return_val_if_fail (name == NULL || g_dbus_is_name (name), NULL);
   g_return_val_if_fail (g_variant_is_object_path (path), NULL);
   g_return_val_if_fail (g_dbus_is_member_name (method), NULL);
-  g_return_val_if_fail (interface == NULL || g_dbus_is_interface_name (interface), NULL);
+  g_return_val_if_fail (interface_ == NULL || g_dbus_is_interface_name (interface_), NULL);
 
   message = g_dbus_message_new ();
   message->priv->type = G_DBUS_MESSAGE_TYPE_METHOD_CALL;
@@ -163,8 +163,8 @@ g_dbus_message_new_method_call (const gchar *name,
     g_dbus_message_set_destination (message, name);
   g_dbus_message_set_path (message, path);
   g_dbus_message_set_member (message, method);
-  if (interface != NULL)
-    g_dbus_message_set_interface (message, interface);
+  if (interface_ != NULL)
+    g_dbus_message_set_interface (message, interface_);
 
   return message;
 }
@@ -172,7 +172,7 @@ g_dbus_message_new_method_call (const gchar *name,
 /**
  * g_dbus_message_new_signal:
  * @path: A valid object path.
- * @interface: A valid D-Bus interface name or %NULL.
+ * @interface_: A valid D-Bus interface name or %NULL.
  * @signal: A valid signal name.
  *
  * Creates a new #GDBusMessage for a signal emission.
@@ -183,14 +183,14 @@ g_dbus_message_new_method_call (const gchar *name,
  */
 GDBusMessage *
 g_dbus_message_new_signal (const gchar  *path,
-                           const gchar  *interface,
+                           const gchar  *interface_,
                            const gchar  *signal)
 {
   GDBusMessage *message;
 
   g_return_val_if_fail (g_variant_is_object_path (path), NULL);
   g_return_val_if_fail (g_dbus_is_member_name (signal), NULL);
-  g_return_val_if_fail (interface == NULL || g_dbus_is_interface_name (interface), NULL);
+  g_return_val_if_fail (interface_ == NULL || g_dbus_is_interface_name (interface_), NULL);
 
   message = g_dbus_message_new ();
   message->priv->type = G_DBUS_MESSAGE_TYPE_SIGNAL;
@@ -199,8 +199,8 @@ g_dbus_message_new_signal (const gchar  *path,
   g_dbus_message_set_path (message, path);
   g_dbus_message_set_member (message, signal);
 
-  if (interface != NULL)
-    g_dbus_message_set_interface (message, interface);
+  if (interface_ != NULL)
+    g_dbus_message_set_interface (message, interface_);
 
   return message;
 }
@@ -965,7 +965,7 @@ parse_value_from_blob (GMemoryInputStream    *mis,
       goffset offset;
       goffset target;
       const GVariantType *element_type;
-      GVariantBuilder *builder;
+      GVariantBuilder builder;
 
       if (!ensure_input_padding (mis, 4, &local_error))
         goto fail;
@@ -981,7 +981,7 @@ parse_value_from_blob (GMemoryInputStream    *mis,
           goto fail;
         }
 
-      builder = g_variant_builder_new (type);
+      g_variant_builder_init (&builder, type);
       element_type = g_variant_type_element (type);
 
       if (array_len == 0)
@@ -1009,21 +1009,21 @@ parse_value_from_blob (GMemoryInputStream    *mis,
                                             &local_error);
               if (item == NULL)
                 {
-                  g_variant_builder_unref (builder);
+                  g_variant_builder_clear (&builder);
                   goto fail;
                 }
-              g_variant_builder_add_value (builder, item);
+              g_variant_builder_add_value (&builder, item);
               offset = g_seekable_tell (G_SEEKABLE (mis));
             }
         }
 
       if (!just_align)
         {
-          ret = g_variant_builder_end (builder);
+          ret = g_variant_builder_end (&builder);
         }
       else
         {
-          g_variant_builder_unref (builder);
+          g_variant_builder_clear (&builder);
         }
     }
   else if (g_variant_type_is_dict_entry (type))
@@ -1069,9 +1069,9 @@ parse_value_from_blob (GMemoryInputStream    *mis,
       if (!just_align)
         {
           const GVariantType *element_type;
-          GVariantBuilder *builder;
+          GVariantBuilder builder;
 
-          builder = g_variant_builder_new (type);
+          g_variant_builder_init (&builder, type);
           element_type = g_variant_type_first (type);
           while (element_type != NULL)
             {
@@ -1083,14 +1083,14 @@ parse_value_from_blob (GMemoryInputStream    *mis,
                                             &local_error);
               if (item == NULL)
                 {
-                  g_variant_builder_unref (builder);
+                  g_variant_builder_clear (&builder);
                   goto fail;
                 }
-              g_variant_builder_add_value (builder, item);
+              g_variant_builder_add_value (&builder, item);
 
               element_type = g_variant_type_next (element_type);
             }
-          ret = g_variant_builder_end (builder);
+          ret = g_variant_builder_end (&builder);
         }
     }
   else if (g_variant_type_is_variant (type))
@@ -1195,8 +1195,12 @@ g_dbus_message_bytes_needed (guchar                *blob,
     }
   else if (blob[0] == 'B')
     {
-      /* TODO */
-      g_assert_not_reached ();
+      /* core header (12 bytes) + ARRAY of STRUCT of (BYTE,VARIANT) */
+      ret = 12 + 4 + GUINT32_FROM_BE (((guint32 *) blob)[3]);
+      /* round up so it's a multiple of 8 */
+      ret = 8 * ((ret + 7)/8);
+      /* finally add the body size */
+      ret += GUINT32_FROM_BE (((guint32 *) blob)[1]);
     }
   else
     {
@@ -1327,8 +1331,7 @@ g_dbus_message_new_from_blob (guchar                *blob,
       const gchar *signature_str;
       gsize signature_str_len;
 
-      signature_str = g_variant_get_string (signature, NULL);
-      signature_str_len = strlen (signature_str);
+      signature_str = g_variant_get_string (signature, &signature_str_len);
 
       /* signature but no body */
       if (message_body_len == 0 && signature_str_len > 0)
@@ -1527,9 +1530,8 @@ append_value_to_blob (GVariant             *value,
       padding_added = ensure_output_padding (mos, dos, 4);
       if (value != NULL)
         {
-          const gchar *v = g_variant_get_string (value, NULL);
           gsize len;
-          len = strlen (v);
+          const gchar *v = g_variant_get_string (value, &len);
           g_data_output_stream_put_uint32 (dos, len, NULL, NULL);
           g_data_output_stream_put_string (dos, v, NULL, NULL);
           g_data_output_stream_put_byte (dos, '\0', NULL, NULL);
@@ -1541,9 +1543,8 @@ append_value_to_blob (GVariant             *value,
       if (value != NULL)
         {
           /* TODO: validate object path */
-          const gchar *v = g_variant_get_string (value, NULL);
           gsize len;
-          len = strlen (v);
+          const gchar *v = g_variant_get_string (value, &len);
           g_data_output_stream_put_uint32 (dos, len, NULL, NULL);
           g_data_output_stream_put_string (dos, v, NULL, NULL);
           g_data_output_stream_put_byte (dos, '\0', NULL, NULL);
@@ -1554,9 +1555,8 @@ append_value_to_blob (GVariant             *value,
       if (value != NULL)
         {
           /* TODO: validate signature (including max len being 255) */
-          const gchar *v = g_variant_get_string (value, NULL);
           gsize len;
-          len = strlen (v);
+          const gchar *v = g_variant_get_string (value, &len);
           g_data_output_stream_put_byte (dos, len, NULL, NULL);
           g_data_output_stream_put_string (dos, v, NULL, NULL);
           g_data_output_stream_put_byte (dos, '\0', NULL, NULL);
@@ -1774,7 +1774,7 @@ g_dbus_message_to_blob (GDBusMessage          *message,
   goffset body_start_offset;
   gsize body_size;
   GVariant *header_fields;
-  GVariantBuilder *builder;
+  GVariantBuilder builder;
   GHashTableIter hash_iter;
   gpointer key;
   GVariant *header_value;
@@ -1826,16 +1826,16 @@ g_dbus_message_to_blob (GDBusMessage          *message,
       goto out;
     }
 
-  builder = g_variant_builder_new (G_VARIANT_TYPE ("a{yv}"));//G_VARIANT_TYPE_ARRAY);
+  g_variant_builder_init (&builder, G_VARIANT_TYPE ("a{yv}"));
   g_hash_table_iter_init (&hash_iter, message->priv->headers);
   while (g_hash_table_iter_next (&hash_iter, &key, (gpointer) &header_value))
     {
-      g_variant_builder_add (builder,
+      g_variant_builder_add (&builder,
                              "{yv}",
                              (guchar) GPOINTER_TO_UINT (key),
                              header_value);
     }
-  header_fields = g_variant_new ("a{yv}", builder);
+  header_fields = g_variant_builder_end (&builder);
 
   if (!append_value_to_blob (header_fields,
                              g_variant_get_type (header_fields),
