@@ -28,7 +28,9 @@
 #error "You must define G_SETTINGS_ENABLE_BACKEND before including <gio/gsettingsbackend.h>."
 #endif
 
-#include <glib-object.h>
+#define __GIO_GIO_H_INSIDE__
+#include <gio/giotypes.h>
+#undef __GIO_GIO_H_INSIDE__
 
 G_BEGIN_DECLS
 
@@ -65,34 +67,42 @@ struct _GSettingsBackendClass
 {
   GObjectClass parent_class;
 
-  gboolean    (*supports_context) (const gchar         *context);
+  gboolean      (*supports_context) (const gchar         *context);
 
-  GVariant *  (*read)             (GSettingsBackend    *backend,
-                                   const gchar         *key,
-                                   const GVariantType  *expected_type,
-                                   gboolean             default_value);
-  gchar **    (*list)             (GSettingsBackend    *backend,
-                                   const gchar         *path,
-                                   gsize               *length);
-  gboolean    (*write)            (GSettingsBackend    *backend,
-                                   const gchar         *key,
-                                   GVariant            *value,
-                                   gpointer             origin_tag);
-  gboolean    (*write_keys)       (GSettingsBackend    *backend,
-                                   GTree               *tree,
-                                   gpointer             origin_tag);
-  void        (*reset)            (GSettingsBackend    *backend,
-                                   const gchar         *key,
-                                   gpointer             origin_tag);
-  void        (*reset_path)       (GSettingsBackend    *backend,
-                                   const gchar         *path,
-                                   gpointer             origin_tag);
-  gboolean    (*get_writable)     (GSettingsBackend    *backend,
-                                   const gchar         *key);
-  void        (*subscribe)        (GSettingsBackend    *backend,
-                                   const gchar         *name);
-  void        (*unsubscribe)      (GSettingsBackend    *backend,
-                                   const gchar         *name);
+  GVariant *    (*read)             (GSettingsBackend    *backend,
+                                     const gchar         *key,
+                                     const GVariantType  *expected_type,
+                                     gboolean             default_value);
+  gchar **      (*list)             (GSettingsBackend    *backend,
+                                     const gchar         *path,
+                                     gchar              **resets,
+                                     gsize                n_resets,
+                                     gsize               *length);
+  gboolean      (*write)            (GSettingsBackend    *backend,
+                                     const gchar         *key,
+                                     GVariant            *value,
+                                     gpointer             origin_tag);
+  gboolean      (*write_keys)       (GSettingsBackend    *backend,
+                                     GTree               *tree,
+                                     gpointer             origin_tag);
+  void          (*reset)            (GSettingsBackend    *backend,
+                                     const gchar         *key,
+                                     gpointer             origin_tag);
+  void          (*reset_path)       (GSettingsBackend    *backend,
+                                     const gchar         *path,
+                                     gpointer             origin_tag);
+  gboolean      (*get_writable)     (GSettingsBackend    *backend,
+                                     const gchar         *key);
+  void          (*subscribe)        (GSettingsBackend    *backend,
+                                     const gchar         *name);
+  void          (*unsubscribe)      (GSettingsBackend    *backend,
+                                     const gchar         *name);
+  void          (*sync)             (GSettingsBackend    *backend);
+
+  GPermission * (*get_permission)   (GSettingsBackend    *backend,
+                                     const gchar         *path);
+
+  gpointer padding[7];
 };
 
 struct _GSettingsBackend
